@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
 from django_models_ext.basemodels import BaseModelMixin, SexModelMixin
+from django_models_ext.fileext import upload_file_path, upload_file_store_path, upload_file_url, upload_path
 from django_models_ext.provincemodels import ProvinceModelMixin, ProvinceShortModelMixin
-from django_models_ext.fileext import upload_path, upload_file_path, upload_file_store_path, upload_file_url
 from django_models_ext.queryext import get_or_create_ext
