@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django_six import gettext_lazy as _
 
 
 class BaseModelMixin(models.Model):
